#[repr(transparent)]pub struct Cmd(pub u32);Expand description
Command register
Tuple Fields
0: u32Implementations
Sourceimpl Cmd
impl Cmd
Sourcepub const fn set_cmd_index(&mut self, val: u8)
pub const fn set_cmd_index(&mut self, val: u8)
Command index.
Sourcepub const fn response_expect(&self) -> bool
pub const fn response_expect(&self) -> bool
Response expect.
Sourcepub const fn set_response_expect(&mut self, val: bool)
pub const fn set_response_expect(&mut self, val: bool)
Response expect.
Sourcepub const fn response_length(&self) -> bool
pub const fn response_length(&self) -> bool
Response length.
Sourcepub const fn set_response_length(&mut self, val: bool)
pub const fn set_response_length(&mut self, val: bool)
Response length.
Sourcepub const fn check_response_crc(&self) -> bool
pub const fn check_response_crc(&self) -> bool
Check response CRC.
Sourcepub const fn set_check_response_crc(&mut self, val: bool)
pub const fn set_check_response_crc(&mut self, val: bool)
Check response CRC.
Sourcepub const fn data_expected(&self) -> bool
pub const fn data_expected(&self) -> bool
Data expected.
Sourcepub const fn set_data_expected(&mut self, val: bool)
pub const fn set_data_expected(&mut self, val: bool)
Data expected.
Sourcepub const fn read_write(&self) -> bool
pub const fn read_write(&self) -> bool
read/write.
Sourcepub const fn set_read_write(&mut self, val: bool)
pub const fn set_read_write(&mut self, val: bool)
read/write.
Sourcepub const fn transfer_mode(&self) -> bool
pub const fn transfer_mode(&self) -> bool
Transfer mode.
Sourcepub const fn set_transfer_mode(&mut self, val: bool)
pub const fn set_transfer_mode(&mut self, val: bool)
Transfer mode.
Sourcepub const fn send_auto_stop(&self) -> bool
pub const fn send_auto_stop(&self) -> bool
Send auto stop.
Sourcepub const fn set_send_auto_stop(&mut self, val: bool)
pub const fn set_send_auto_stop(&mut self, val: bool)
Send auto stop.
Sourcepub const fn wait_prvdata_complete(&self) -> bool
pub const fn wait_prvdata_complete(&self) -> bool
Wait prvdata complete.
Sourcepub const fn set_wait_prvdata_complete(&mut self, val: bool)
pub const fn set_wait_prvdata_complete(&mut self, val: bool)
Wait prvdata complete.
Sourcepub const fn stop_abort_cmd(&self) -> bool
pub const fn stop_abort_cmd(&self) -> bool
Stop abort command.
Sourcepub const fn set_stop_abort_cmd(&mut self, val: bool)
pub const fn set_stop_abort_cmd(&mut self, val: bool)
Stop abort command.
Sourcepub const fn send_initialization(&self) -> bool
pub const fn send_initialization(&self) -> bool
Send initialization.
Sourcepub const fn set_send_initialization(&mut self, val: bool)
pub const fn set_send_initialization(&mut self, val: bool)
Send initialization.
Sourcepub const fn card_number(&self) -> CardNumber
pub const fn card_number(&self) -> CardNumber
Specifies the card number of SDCARD for which the current Command is being executed
Sourcepub const fn set_card_number(&mut self, val: CardNumber)
pub const fn set_card_number(&mut self, val: CardNumber)
Specifies the card number of SDCARD for which the current Command is being executed
Sourcepub const fn update_clock_registers_only(&self) -> bool
pub const fn update_clock_registers_only(&self) -> bool
Update clock registers only.
Sourcepub const fn set_update_clock_registers_only(&mut self, val: bool)
pub const fn set_update_clock_registers_only(&mut self, val: bool)
Update clock registers only.
Sourcepub const fn read_ceata_device(&self) -> bool
pub const fn read_ceata_device(&self) -> bool
Read ceata device.
Sourcepub const fn set_read_ceata_device(&mut self, val: bool)
pub const fn set_read_ceata_device(&mut self, val: bool)
Read ceata device.
Sourcepub const fn ccs_expected(&self) -> bool
pub const fn ccs_expected(&self) -> bool
CCS expected.
Sourcepub const fn set_ccs_expected(&mut self, val: bool)
pub const fn set_ccs_expected(&mut self, val: bool)
CCS expected.
Sourcepub const fn enable_boot(&self) -> bool
pub const fn enable_boot(&self) -> bool
Enable Boot - this bit should be set only for mandatory boot mode.
Sourcepub const fn set_enable_boot(&mut self, val: bool)
pub const fn set_enable_boot(&mut self, val: bool)
Enable Boot - this bit should be set only for mandatory boot mode.
Sourcepub const fn expect_boot_ack(&self) -> bool
pub const fn expect_boot_ack(&self) -> bool
Expect Boot Acknowledge.
Sourcepub const fn set_expect_boot_ack(&mut self, val: bool)
pub const fn set_expect_boot_ack(&mut self, val: bool)
Expect Boot Acknowledge.
Sourcepub const fn disable_boot(&self) -> bool
pub const fn disable_boot(&self) -> bool
Disable Boot.
Sourcepub const fn set_disable_boot(&mut self, val: bool)
pub const fn set_disable_boot(&mut self, val: bool)
Disable Boot.
Sourcepub const fn set_boot_mode(&mut self, val: bool)
pub const fn set_boot_mode(&mut self, val: bool)
Boot Mode.
Sourcepub const fn volt_switch(&self) -> bool
pub const fn volt_switch(&self) -> bool
Voltage switch bit.
Sourcepub const fn set_volt_switch(&mut self, val: bool)
pub const fn set_volt_switch(&mut self, val: bool)
Voltage switch bit.
Sourcepub const fn use_hold_reg(&self) -> bool
pub const fn use_hold_reg(&self) -> bool
Use Hold Register.
Sourcepub const fn set_use_hold_reg(&mut self, val: bool)
pub const fn set_use_hold_reg(&mut self, val: bool)
Use Hold Register.
Sourcepub const fn set_start_cmd(&mut self, val: bool)
pub const fn set_start_cmd(&mut self, val: bool)
Start command.