nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Fifoth

Struct Fifoth 

#[repr(transparent)]
pub struct Fifoth(pub u32);
FIFO Threshold Watermark register

Tuple Fields

0: u32

Implementations

Source

impl Fifoth

pub const fn tx_wmark(&self) -> u16

FIFO threshold watermark level when transmitting data to card.

pub const fn set_tx_wmark(&mut self, val: u16)

FIFO threshold watermark level when transmitting data to card.

pub const fn rx_wmark(&self) -> u16

FIFO threshold watermark level when receiving data to card.

pub const fn set_rx_wmark(&mut self, val: u16)

FIFO threshold watermark level when receiving data to card.

pub const fn dma_mts(&self) -> u8

Burst size of multiple transaction; should be programmed same as DW-DMA controller multiple-transaction-size SRC/DEST_MSIZE.

pub const fn set_dma_mts(&mut self, val: u8)

Burst size of multiple transaction; should be programmed same as DW-DMA controller multiple-transaction-size SRC/DEST_MSIZE.