#[repr(transparent)]pub struct Fifoth(pub u32);Expand description
FIFO Threshold Watermark register
Tuple Fields
0: u32Implementations
Sourceimpl Fifoth
impl Fifoth
Sourcepub const fn tx_wmark(&self) -> u16
pub const fn tx_wmark(&self) -> u16
FIFO threshold watermark level when transmitting data to card.
Sourcepub const fn set_tx_wmark(&mut self, val: u16)
pub const fn set_tx_wmark(&mut self, val: u16)
FIFO threshold watermark level when transmitting data to card.
Sourcepub const fn rx_wmark(&self) -> u16
pub const fn rx_wmark(&self) -> u16
FIFO threshold watermark level when receiving data to card.
Sourcepub const fn set_rx_wmark(&mut self, val: u16)
pub const fn set_rx_wmark(&mut self, val: u16)
FIFO threshold watermark level when receiving data to card.
Sourcepub const fn dma_mts(&self) -> u8
pub const fn dma_mts(&self) -> u8
Burst size of multiple transaction; should be programmed same as DW-DMA controller multiple-transaction-size SRC/DEST_MSIZE.
Sourcepub const fn set_dma_mts(&mut self, val: u8)
pub const fn set_dma_mts(&mut self, val: u8)
Burst size of multiple transaction; should be programmed same as DW-DMA controller multiple-transaction-size SRC/DEST_MSIZE.